import { Abstract, Access, Async, Extern, New, Override, Sealed, Static, Virtual } from './access-modifier';
import { Class } from './class';
import { Expression, ExpressionOrLiteral } from './expression';
import { Parameter } from './parameter';
import { StatementPossibilities, Statements } from './statements/statement';
import { TypeDeclaration } from './type-declaration';
export declare class Method extends Statements {
    name: string;
    protected returnType: TypeDeclaration;
    parameters: Parameter[];
    'new': New;
    access: Access;
    'static': Static;
    virtual: Virtual;
    sealed: Sealed;
    override: Override;
    abstract: Abstract;
    extern: Extern;
    async: Async;
    isPartial: boolean;
    description: string;
    returnsDescription: string;
    body?: StatementPossibilities | Expression;
    constructor(name: string, returnType?: TypeDeclaration, objectIntializer?: Partial<Method>);
    addParameter(parameter: Parameter): Parameter;
    protected readonly summaryDocumentation: string;
    protected readonly parameterDocumentation: string;
    protected readonly returnsDocumentation: string;
    readonly declaration: string;
    readonly interfaceDeclaration: string;
    readonly implementation: string;
    invoke(...parameters: Array<ExpressionOrLiteral>): Expression;
    addTo(parent: Class): Method;
}
export declare class PartialMethod extends Method {
    isPartial: boolean;
    constructor(name: string, returnType?: TypeDeclaration, objectIntializer?: Partial<PartialMethod>);
    readonly declaration: string;
    readonly implementation: string;
}
export declare class LambdaMethod extends Method {
    protected expression: Expression;
    constructor(name: string, returnType: TypeDeclaration | undefined, expression: Expression, objectIntializer?: Partial<PartialMethod>);
    readonly declaration: string;
    readonly implementation: string;
}
export declare class ImplicitCastOperator extends Method {
    protected expression: ExpressionOrLiteral;
    constructor(targetType: TypeDeclaration, sourceType: TypeDeclaration, expression: ExpressionOrLiteral, objectIntializer?: Partial<ImplicitCastOperator>);
    readonly declaration: string;
    readonly implementation: string;
}
//# sourceMappingURL=method.d.ts.map